options(OutDec=",")

setwd("~/Recherche/Homogamie/EPIC")
indiv <- read.csv("Données EPIC 25-01/individu.csv")
hist.orig <- read.csv("Données EPIC 25-01/histoire.csv")
#rep <- read.csv("Données EPIC 25-01/repondant.csv")

# Données avec les scores Chambaz-Maurin-Torelli
rep <- read.csv("Données EPIC 25-01/Scores/epic_rep.csv")

# Normaliser les scores de 0 à 100
rep$score_pro_enq_act <- (rep$score_pro_enq_act + 1.52) * 100/(2.19+1.52)
rep$score_pro_conj_act <- (rep$score_pro_conj_act + 1.52) * 100/(2.19+1.52)
rep$score_pro_enq_debract <- (rep$score_pro_enq_debract + 1.52) * 100/(2.19+1.52)
rep$score_pro_conj_debract <- (rep$score_pro_conj_debract + 1.52) * 100/(2.19+1.52)

rep$diff_act <- abs(rep$score_pro_enq_act - rep$score_pro_conj_act)
rep$ecart_act <- rep$score_pro_enq_act - rep$score_pro_conj_act
rep$ecart_debract <- rep$score_pro_enq_debract - rep$score_pro_conj_debract

rep$IDENT_MEN <- as.character(rep$IDENT_MEN)

# On revient à hist sans les variables rep pour re-fusionner plus bas
# après modification des variables
hist <- read.csv("Données EPIC 25-01/Scores/epic_histrep.csv")
hist <- hist[hist$IDENT_MEN %in% hist.orig$IDENT_MEN, c("IDENT_MEN", setdiff(colnames(hist), colnames(rep)))]
rm(hist.orig)
hist$IDENT_MEN <- as.character(hist$IDENT_MEN)

hist$ecart_debrhist <- hist$score_pro_enq_debrhist - hist$score_pro_conj_debrhist

rep$SEXER <- factor(rep$SEXER, levels=1:2, labels=c("H", "F"))
hist$H_ADEB[hist$H_ADEB == 9999] <- NA
rep$H_ANAISC_C[rep$H_ANAISC_C == 9999] <- NA
rep$ANAISR10 <- cut(rep$ANAISR, seq(1948, 1988, by=10), right=TRUE,
                    labels=paste(seq(1948, 1978, by=10), seq(1957, 1987, by=10), sep="-"))

dip <- function(dip) {
  dip <- factor(dip, levels=1:9, labels=c("Aucun", "CEP", "BEPC", "CAP/BEP",
                                          "Bac", "Bac+2", "Bac+3/Bac+4", "Bac+5", "Doctorat"))
  dip[dip == "CEP"] <- "BEPC"
  dip[dip == "Doctorat"] <- "Bac+5"
  levels(dip)[levels(dip) == "CEP/BEPC"] <- "CEP/BEPC"
  levels(dip)[levels(dip) == "Bac+5"] <- ">= Bac+5"
  factor(dip)
}
rep$M_dip <- dip(rep$M_DIPLOME)
rep$C_dipC <- dip(rep$C_DIPLOMEC)

pcs <- function(pcsdet) {
  pcs <- floor(as.numeric(as.character(pcsdet))/10)
  pcs <- factor(pcs, levels=1:6,
                labels=c("Agriculteur", "Indépendant", "Cadre", "Intermédiaire",
                         "Employé", "Ouvrier"))
  
  pcs
}

# Cf. Burnod & Chenu (2001), p. 100 et 97
pcs2 <- function(pcsdet) {
  pcs <- floor(as.numeric(as.character(pcsdet))/10)
  pcs[pcs > 6] <- NA
  pcs2 <- factor(pcs, levels=1:8,
                 labels=c("Agriculteur", "Indépendant", "Cadre", "Intermédiaire",
                          "Employé qualifié", "Employé non qualifié", "Ouvrier qualifié", "Ouvrier non qualifié"))
  pcs2[pcsdet %in% c("50", "52", "53", "54")] <- "Employé qualifié"
  pcs2[pcsdet %in% c("55", "56")] <- "Employé non qualifié"
# Impossible à faire avec les données EPIC
# pcs2[substr(p, 1, 3) %in% c("525", "526", "534")] <- "Employé non qualifié"
  pcs2[pcsdet %in% c("60", "62", "63", "64", "65")] <- "Ouvrier qualifié"
  pcs2[pcsdet %in% c("67", "68", "69")] <- "Ouvrier non qualifié"

  pcs2
}

pcs3 <- function(pcs2) {
  pcs3 <- pcs2
  levels(pcs3) <- c("Agriculteur", "Indépendant", "Cadre", "Intermédiaire",
                    "Employé/ouvrier qualifié", "Employé/ouvrier non qualifié",
                    "Employé/ouvrier qualifié", "Employé/ouvrier non qualifié")
  pcs3
}

act <- function(act) {
  factor(act, levels=1:10, labels=c("Salarié ou indépendant", "Aide familial", "Apprenti ou stagiaire",
                                    "Étudiant", "Chômeur", "Retraité", "Congé parental", "Congé maladie",
                                    "Au foyer", "Autre"))
}

sitpro <- function(sitpro) {
  factor(sitpro, levels=1:7, labels=c("Étudiant", "En emploi", "Au chômage", "Au foyer ou inactif",
                                      "Retraité", "Service militaire", "Autre"))
}

rep$M_CS8b <- pcs2(rep$M_CS42) # CS d'Ego à l'enquête
rep$C_CS8bC <- pcs2(rep$C_CS42C) # CS du conjoint actuel à l'enquête
rep$H_CS8b_C <- pcs2(rep$H_CS42_C) # CS d'Ego au début de la relation actuelle
rep$H_CS8bC_C <- pcs2(rep$H_CS42C_C) # CS du conjoint actuel au début de la relation
hist$H_CS8b <- pcs2(hist$H_CS42) # CS d'Ego au début de la première relation
hist$H_CS8bC <- pcs2(hist$H_CS42C) # CS du premier conjoint au début de la relation

rep$M_CS6 <- pcs3(rep$M_CS8b) # CS d'Ego à l'enquête
rep$C_CS6C <- pcs3(rep$C_CS8bC) # CS du conjoint actuel à l'enquête
rep$H_CS6_C <- pcs3(rep$H_CS8b_C) # CS d'Ego au début de la relation actuelle
rep$H_CS6C_C <- pcs3(rep$H_CS8bC_C) # CS du conjoint actuel au début de la relation
hist$H_CS6 <- pcs3(hist$H_CS8b) # CS d'Ego au début de la première relation
hist$H_CS6C <- pcs3(hist$H_CS8bC) # CS du premier conjoint au début de la relation

rep$F_CS6P <- pcs(rep$F_CS42P) # CS principale du père d'Ego
rep$F_CS6M <- pcs(rep$F_CS42M) # CS principale de la mère d'Ego
rep$C_CS6PC <- pcs(rep$C_CS42PC) # CS du père du conjoint à l'enquête
rep$C_CS6MC <- pcs(rep$C_CS42MC) # CS du père du conjoint à l'enquête
rep$cspp <- rep$F_CS6P # CS du père, ou à défaut de la mère
rep$cspp[is.na(rep$F_CS6P)] <- rep$F_CS6M[is.na(rep$F_CS6P)]

rep$M_ACTb <- act(rep$M_ACT) # Activité d'Ego à l'enquête
rep$C_ACTCb <- act(rep$C_ACTC) # Activité du conjoint actuel à l'enquête
rep$H_SITPRO_Cb <- sitpro(rep$H_SITPRO_C) # Activité d'Ego au début de la relation actuelle
rep$H_SITPROC_Cb <- sitpro(rep$H_SITPROC_C) # Activité du conjoint actuel au début de la relation
hist$H_SITPROb <- sitpro(hist$H_SITPRO) # Activité d'Ego au début de la relation
hist$H_SITPROCb <- sitpro(hist$H_SITPROC) # Activité du conjoint au début de la relation

rep$H_homocs8b_C <- factor(ifelse(rep$H_CS8b_C == rep$H_CS8bC_C, "Homogame", "Hétérogame"),
                           levels=c("Homogame", "Hétérogame"))
rep$C_homocs8b <- factor(ifelse(rep$M_CS8b == rep$C_CS8bC, "Homogame", "Hétérogame"),
                         levels=c("Homogame", "Hétérogame"))
hist$H_homocs8b <- factor(ifelse(hist$H_CS8b == hist$H_CS8bC, "Homogame", "Hétérogame"),
                          levels=c("Homogame", "Hétérogame"))
rep$H_homocs8b_C <- factor(ifelse(rep$H_CS8b_C == rep$H_CS8bC_C, "Homogame", "Hétérogame"),
                           levels=c("Homogame", "Hétérogame"))

homocs6 <- function(CS6, CS6C) {
  homocs6 <- ifelse(CS6 == CS6C, "Homogame", "Hétérogame")
  factor(homocs6, levels=c("Homogame", "Hétérogame"))
}

homocs6b <- function(homocs6, SITPRO, SITPROC) {
  homocs6b <- factor(homocs6, levels=c("Homogame", "Hétérogame", "1 étudiant", "2 étudiants"))
  homocs6b[SITPRO == "Étudiant" | SITPROC == "Étudiant"] <- "1 étudiant"
  homocs6b[SITPRO == "Étudiant" & SITPROC == "Étudiant"] <- "2 étudiants"
  homocs6b
}

rep$C_homodip <- factor(ifelse(rep$M_dip == rep$C_dipC, "Homogame", "Hétérogame"),
                        levels=c("Homogame", "Hétérogame"))
rep$C_hyperdip <- factor(ifelse(rep$M_dip == rep$C_dipC, "Homo",
                                ifelse(as.integer(rep$M_dip) < as.integer(rep$C_dipC), "Hyper", "Hypo")),
                         levels=c("Homo", "Hyper", "Hypo"))

rep$H_homocs6_C <- homocs6(rep$H_CS6_C, rep$H_CS6C_C)
rep$H_homocs6_Cb <- homocs6b(rep$H_homocs6_C, rep$H_SITPRO_Cb, rep$H_SITPROC_Cb)

rep$C_homocs6 <- homocs6(rep$M_CS6, rep$C_CS6C)
rep$C_homocs6b <- homocs6b(rep$C_homocs6, rep$M_ACTb, rep$C_ACTCb)
rep$C_homocs6p <- homocs6(rep$F_CS6P, rep$C_CS6PC)

hist$H_homocs6 <- homocs6(hist$H_CS6, hist$H_CS6C)
hist$H_homocs6b <- homocs6b(hist$H_homocs6, hist$H_SITPROb, hist$H_SITPROCb)

rep$C_duree <- 2014 - rep$C_ADEB
rep$C_duree[rep$C_duree < 0] <- NA
rep$C_duree10 <- cut(rep$C_duree, c(0, 5, 10, 20, 30, 100), right=FALSE,
                     labels=c("- de 5 ans", "5-10 ans", "10-19 ans", "20-29 ans", "30 ans et +"))
hist$H_duree <- hist$H_AFIN - hist$H_ADEB
hist$H_duree[hist$H_FIN == "1"] <- 2014 - hist$H_ADEB[hist$H_FIN == "1"]
hist$H_duree[abs(hist$H_duree) > 50] <- NA
hist$H_duree10 <- cut(hist$H_duree, c(0, 5, 10, 20, 30, 100), right=FALSE,
                      labels=c("- de 5 ans", "5-10 ans", "10-19 ans", "20-29 ans", "30 ans et +"))

hist$H_SITECO <- factor(hist$H_SITECO, levels=1:5, labels=c("++", "+", "=", "-", "--"))
hist$H_SITECO2 <- hist$H_SITECO
levels(hist$H_SITECO2) <- c("--", "-", "+", "-", "--")

hist$H_RESMAT <- factor(hist$H_RESMAT, levels=1:4, labels=c("++", "+", "-", "--"))
hist$H_DIFFIN2 <- factor(NA, levels=c("Homo ++", "Homo +", "Hypo", "Hyper"))
hist$H_DIFFIN2[hist$H_RESMAT == "++"] <- "Homo ++"
hist$H_DIFFIN2[hist$H_RESMAT == "+"] <- "Homo +"
hist$H_DIFFIN2[hist$H_DIFFIN == 1] <- "Hypo"
hist$H_DIFFIN2[hist$H_DIFFIN == 2] <- "Hyper"
hist$H_RESREL <- factor(hist$H_RESREL, levels=1:4, labels=c("++", "+", "-", "--"))
hist$H_RESLOI <- factor(hist$H_RESLOI, levels=1:4, labels=c("++", "+", "-", "--"))
hist$H_RESEDU <- factor(hist$H_RESEDU, levels=1:4, labels=c("++", "+", "-", "--"))
hist$H_RESPOL <- factor(hist$H_RESPOL, levels=1:4, labels=c("++", "+", "-", "--"))
#hist$H_SITECO <- addNA(hist$H_SITECO)
#hist$H_RESMAT <- addNA(hist$H_RESMAT)
#hist$H_RESREL <- addNA(hist$H_RESREL)
#hist$H_RESLOI <- addNA(hist$H_RESLOI)
#hist$H_RESEDU <- addNA(hist$H_RESEDU)
#hist$H_RESPOL <- addNA(hist$H_RESPOL)

rep$H_DIFFIN2_C <- factor(NA, levels=c("Homo ++", "Homo +", "Hypo", "Hyper"))
rep$H_DIFFIN2_C[rep$H_RESMAT_C == "++"] <- "Homo ++"
rep$H_DIFFIN2_C[rep$H_RESMAT_C == "+"] <- "Homo +"
rep$H_DIFFIN2_C[rep$H_DIFFIN_C == 1] <- "Hypo"
rep$H_DIFFIN2_C[rep$H_DIFFIN_C == 2] <- "Hyper"
rep$H_RESREL_C <- factor(rep$H_RESREL_C, levels=1:4, labels=c("++", "+", "-", "--"))
rep$H_RESLOI_C <- factor(rep$H_RESLOI_C, levels=1:4, labels=c("++", "+", "-", "--"))
rep$H_RESEDU_C <- factor(rep$H_RESEDU_C, levels=1:4, labels=c("++", "+", "-", "--"))
rep$H_RESPOL_C <- factor(rep$H_RESPOL_C, levels=1:4, labels=c("++", "+", "-", "--"))
rep$H_RESMAT_C <- factor(rep$H_RESMAT_C, levels=1:4, labels=c("++", "+", "-", "--"))

# Non classés (NA) : 14, 17
rep$H_LIEU_agr_C <- factor(NA, levels=c("Internet", "Lieux publics", "Loisirs",
                                        "Études", "Travail", "Amis", "Famille"))
Encoding(levels(rep$H_LIEU_agr_C)) <- "UTF-8"
rep$H_LIEU_agr_C[rep$H_LIEU1_C == 2] <- "Études"
rep$H_LIEU_agr_C[rep$H_LIEU1_C == 3] <- "Travail"
rep$H_LIEU_agr_C[rep$H_LIEU1_C %in% 15:16] <- "Internet"
rep$H_LIEU_agr_C[rep$H_LIEU1_C %in% c(7, 8, 10, 12)] <- "Lieux publics"
rep$H_LIEU_agr_C[rep$H_LIEU1_C %in% c(4, 5)] <- "Amis"
rep$H_LIEU_agr_C[rep$H_LIEU1_C %in% c(1, 9)] <- "Famille"
rep$H_LIEU_agr_C[rep$H_LIEU1_C %in% c(6, 11, 13)] <- "Loisirs"

hist$H_LIEU_agr <- factor(NA, levels=c("Internet", "Lieux publics", "Loisirs",
                                       "Études", "Travail", "Amis", "Famille"))
Encoding(levels(hist$H_LIEU_agr)) <- "UTF-8"
hist$H_LIEU_agr[hist$H_LIEU1 == 2] <- "Études"
hist$H_LIEU_agr[hist$H_LIEU1 == 3] <- "Travail"
hist$H_LIEU_agr[hist$H_LIEU1 %in% 15:16] <- "Internet"
hist$H_LIEU_agr[hist$H_LIEU1 %in% c(7, 8, 10, 12)] <- "Lieux publics"
hist$H_LIEU_agr[hist$H_LIEU1 %in% c(4, 5)] <- "Amis"
hist$H_LIEU_agr[hist$H_LIEU1 %in% c(1, 9)] <- "Famille"
hist$H_LIEU_agr[hist$H_LIEU1 %in% c(6, 11, 13)] <- "Loisirs"

hist$H_HABENS <- factor(hist$H_HABENS, levels=c("1", "2", "3"), labels=c("Cohabité", "Alterné", "Pas cohabité"))
rep$H_HABENS_C <- factor(rep$H_HABENS_C, levels=c("1", "2", "3"), labels=c("Cohabité", "Alterné", "Pas cohabité"))
rep$H_HABENS_C[rep$M_COUCOHA == "1"] <- "Cohabité"

rep$H_premcoup_C <- factor(rep$H_NREL_C == 1,
                           levels=c(TRUE, FALSE), labels=c("Première union", "Union ultérieure"))
rep$H_premcoupC_C <- factor(rep$H_COUC_C,
                            levels=c("2", "1"), labels=c("Première union", "Union ultérieure"))

hist <- hist[order(hist$IDENT_MEN, hist$H_NREL_CORR),]
hist <- merge(rep, hist, by="IDENT_MEN", all=TRUE)

# Pour ne garder que les couples qui ont cohabité
#rep <- subset(rep, H_HABENS_C == "Cohabité")
#hist <- subset(hist, H_HABENS == "Cohabité")

hist1 <- subset(hist, !duplicated(IDENT_MEN))

rep$C_agedeb <- rep$C_ADEB - rep$ANAISR
rep$H_agedeb_C <- rep$C_ADEB - rep$H_ANAISC_C
rep$temps_etude <- rep$C_agedeb < rep$M_AGEFINET

hist$H_agedeb <- hist$H_ADEB - hist$ANAISR
hist$H_agedeb_C <- hist$H_ADEB - hist$H_ANAISC_imp
hist1$H_agedeb <- hist1$H_ADEB - hist1$ANAISR
hist1$H_agedeb_C <- hist1$H_ADEB - hist1$H_ANAISC_imp
hist$temps_etude <- hist$H_agedeb < hist$M_AGEFINET

library(survey)
svyrep <- svydesign(id=~1, weight=~poids_nr_cal_janv15, data=rep)
svyhist <- svydesign(id=~1, weight=~poids_nr_cal_janv15, data=hist)
svyhist1 <- svydesign(id=~1, weight=~poids_nr_cal_janv15, data=hist1)

svyrep.sym <- function(svyrep, S) {
  res <- svyrep
  pos <- res$variables$SEXER == S

  res$variables$ecart_act[pos] <- -res$variables$ecart_act[pos]
  res$variables$ecart_debract[pos] <- -res$variables$ecart_debract[pos]

  tmp <- res$variables$score_pro_enq_act[pos]
  res$variables$score_pro_enq_act[pos] <- res$variables$score_pro_conj_act[pos]
  res$variables$score_pro_conj_act[pos] <- tmp

  tmp <- res$variables$score_pro_enq_debract[pos]
  res$variables$score_pro_enq_debract[pos] <- res$variables$score_pro_conj_debract[pos]
  res$variables$score_pro_conj_debract[pos] <- tmp

  tmp <- res$variables$H_agedeb_C[pos]
  res$variables$H_agedeb_C[pos] <- res$variables$C_agedeb[pos]
  res$variables$C_agedeb[pos] <- tmp

  tmp <- res$variables$C_hyperdip
  res$variables$C_hyperdip[pos & tmp == "Hyper"] <- "Hypo"
  res$variables$C_hyperdip[pos & tmp == "Hypo"] <- "Hyper"

  tmp <- res$variables$M_act[pos]
  res$variables$M_act[pos] <- res$variables$C_actC[pos]
  res$variables$C_actC[pos] <- tmp

  tmp <- res$variables$M_dip[pos]
  res$variables$M_dip[pos] <- res$variables$C_dipC[pos]
  res$variables$C_dipC[pos] <- tmp

  tmp <- res$variables$F_CS6P[pos]
  res$variables$F_CS6P[pos] <- res$variables$C_CS6PC[pos]
  res$variables$C_CS6PC[pos] <- tmp
  
  tmp <- res$variables$H_premcoup_C[pos]
  res$variables$H_premcoup_C[pos] <- res$variables$H_premcoupC_C[pos]
  res$variables$H_premcoupC_C[pos] <- tmp

  res
}
svyrep.symH <- svyrep.sym(svyrep, "F")
svyrep.symF <- svyrep.sym(svyrep, "H")


svyhist.symH <- svyhist
pos <- svyhist.symH$variables$SEXER == "F"
svyhist.symH$variables$ecart_debrhist[pos] <- -svyhist.symH$variables$ecart_debrhist[pos]
svyhist.symH$variables$H_agedeb[pos] <- svyhist.symH$variables$H_agedeb_C[pos]
svyhist.symH$variables$ANAISR[pos] <- svyhist.symH$variables$H_ANAISC_imp[pos]

svyhist.symF <- svyhist
pos <- svyhist.symF$variables$SEXER == "H"
svyhist.symF$variables$ecart_debrhist[pos] <- -svyhist.symF$variables$ecart_debrhist[pos]
svyhist.symF$variables$H_agedeb[pos] <- svyhist.symF$variables$H_agedeb_C[pos]
svyhist.symF$variables$ANAISR[pos] <- svyhist.symF$variables$H_ANAISC_imp[pos]

svyhist1.symH <- subset(svyhist.symH, H_NREL_CORR == 1)
svyhist1.symF <- subset(svyhist.symF, H_NREL_CORR == 1)
svyhist1.sym <- svyhist1.symH
